<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation>&lt;dependiente de la configuración regional&gt;</translation>
    </message>
</context>
<context>
    <name>LXQtClock</name>
    <message>
        <location filename="../../../lxqtclock.cpp" line="57"/>
        <source>Date&amp;Time (clock) plugin is deprecated</source>
        <translation>El complemento Fecha y hora (reloj) está obsoleto</translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="58"/>
        <source>The &lt;strong&gt;clock&lt;/strong&gt; plugin is deprecated and will be removed in future version of LXQt. Consider replacing it with &lt;strong&gt;worldclock&lt;/strong&gt;.&lt;br/&gt;</source>
        <translation>El complemento &lt;strong&gt;reloj&lt;/strong&gt; está obsoleto y será eliminado en una versión futura de LXQt. Considere sustituirlo por &lt;strong&gt;Reloj mundial&lt;/strong&gt;.&lt;br/&gt;</translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="60"/>
        <source>don&apos;t show this again</source>
        <translation>no mostrar de nuevo</translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <source>LXQt Clock Settings</source>
        <translation type="vanished">Configuración del reloj de LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation>Configuración del reloj</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation>Hora</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation>&amp;Mostrar los segundos</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation>Estilo de 12 &amp;horas</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation>&amp;Usar UTC</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation>&amp;Formato de fecha</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation>No mostrar la fecha</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation>Mostrar la fecha antes que la hora</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation>Mostrar la fecha después de la hora</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation>Mostrar la fecha bajo la hora en una &amp;línea nueva</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation>Primer día de la semana en el calendario</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation>Orientación</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>&amp;Rotar automáticamente cuando el panel esté vertical</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation type="vanished">&amp;Fuente</translation>
    </message>
    <message>
        <source>Font</source>
        <translation type="vanished">Fuente</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Show &amp;date</source>
        <translation type="vanished">Mostrar &amp;fecha</translation>
    </message>
    <message>
        <source>D&amp;ate format</source>
        <translation type="vanished">Formato de &amp;fecha</translation>
    </message>
    <message>
        <source>Fon&amp;t</source>
        <translation type="vanished">Fuen&amp;te</translation>
    </message>
    <message>
        <source>Show date in &amp;new line</source>
        <translation type="vanished">Mostrar fecha en &amp;nueva línea</translation>
    </message>
    <message>
        <source>&amp;Use theme fonts</source>
        <translation type="vanished">&amp;Usar fuente del tema</translation>
    </message>
    <message>
        <source>Time font</source>
        <translation type="vanished">Fuente de la hora</translation>
    </message>
    <message>
        <source>Date font</source>
        <translation type="vanished">Fuente de la fecha</translation>
    </message>
    <message>
        <source>Ultra light</source>
        <translation type="vanished">Ultra ligero</translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="vanished">Ligero</translation>
    </message>
    <message>
        <source>Ultra black</source>
        <translation type="vanished">Ultra negro</translation>
    </message>
    <message>
        <source>Black</source>
        <translation type="vanished">Negro</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="vanished">Negrita</translation>
    </message>
    <message>
        <source>Demi bold</source>
        <translation type="vanished">Semi negrita</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="vanished">Cursiva</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation>Introducir un formato de fecha personalizado</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation>Las secuencias de formato de fecha interpretadas son:

d	el día como número sin cero de relleno (1 a 31)
dd	el día como número con cero de relleno (01 a 31)
ddd	el nombre del día abreviado en la configuración regional (p. ej. &apos;Lun&apos; a &apos;Dom&apos;).
dddd	el nombre del día en la configuración regional (p. ej. &apos;Lunes&apos; a &apos;Domingo&apos;).
M	el mes como número sin cero de relleno (1-12)
MM	el mes como número sin cero de relleno (01-12)
MMM	el nombre del mes abreviado en la configuración regional (p. ej. &apos;Ene&apos; a &apos;Dic&apos;).
MMMM	el nombre del mes en la configuración regional (p. ej. &apos;Enero&apos; a &apos;Diciembre&apos;).
yy	el año como número de dos dígitos (00-99)
yyyy	el año como número de cuatro dígitos

Todo lo demás se interpretará como texto.
Cualquier secuencia de caracteres entre comillas simples (&apos;)
también será tratada como texto y no se usará como una expresión.


Formato de fecha personalizado:</translation>
    </message>
</context>
</TS>
